bd82x6x, ibexpeak, lynxpoint: Declare NVSA before its use.

Windows chokes if it's not the case.

Change-Id: I3df15228ed00c3124b8d42fc01d7d63ff3fe07ba
Signed-off-by: Vladimir Serbinenko <phcoder@gmail.com>
Reviewed-on: http://review.coreboot.org/7017
Tested-by: build bot (Jenkins)
Reviewed-by: Aaron Durbin <adurbin@gmail.com>
diff --git a/src/southbridge/intel/bd82x6x/lpc.c b/src/southbridge/intel/bd82x6x/lpc.c
index a1c7c2a..6218874 100644
--- a/src/southbridge/intel/bd82x6x/lpc.c
+++ b/src/southbridge/intel/bd82x6x/lpc.c
@@ -671,7 +671,7 @@
 	}
 }
 
-static unsigned long southbridge_fill_ssdt(unsigned long current, const char *oem_table_id)
+static void southbridge_inject_dsdt(void)
 {
 	global_nvs_t *gnvs = cbmem_add (CBMEM_ID_ACPI_GNVS, sizeof (*gnvs));
 	void *opregion;
@@ -690,13 +690,11 @@
 		/* And tell SMI about it */
 		smm_setup_structures(gnvs, NULL, NULL);
 
 		/* Add it to SSDT.  */
 		scopelen = acpigen_write_scope("\\");
 		scopelen += acpigen_write_name_dword("NVSA", (u32) gnvs);
 		acpigen_patch_len(scopelen - 1);
 	}
-
-	return (unsigned long) (acpigen_get_current());
 }
 
 static struct pci_operations pci_ops = {
@@ -708,7 +706,7 @@
 	.set_resources		= pci_dev_set_resources,
 	.enable_resources	= pch_lpc_enable_resources,
 	.write_acpi_tables      = acpi_write_hpet,
-	.acpi_fill_ssdt_generator = southbridge_fill_ssdt,
+	.acpi_inject_dsdt_generator = southbridge_inject_dsdt,
 	.init			= lpc_init,
 	.enable			= pch_lpc_enable,
 	.scan_bus		= scan_static_bus,
@@ -690,13 +690,11 @@
 		smm_setup_structures(gnvs, NULL, NULL);
 
-		/* Add it to SSDT.  */
+		/* Add it to DSDT.  */
 		scopelen = acpigen_write_scope("\\");
 		scopelen += acpigen_write_name_dword("NVSA", (u32) gnvs);